/*
    Project: TCTEMP
    Version: V1.20
    File   : na_fileinfoquery.c

    Copyright (c) 2006-2010 Author of TCTEMP. All rights reserved.
    Public Key Fingerprint: 75EB 6BC2 01B7 F6E7 4BD7 CC58 4A5F C393 19EE 6E69

    Covered by TrueCrypt License 2.3 the full text of which is contained
    in the file License.txt included in TCTEMP binary and source code
    distribution archives.

    The copyright notice of this source code file and the public key
    fingerprint must be retained in full.
*/

#include "na_priv.h"

BOOL NAAPI NaQueryFileInfo(HANDLE hFile, PVOID pFileInformation,
  ULONG ulFileInformationSize, FILE_INFORMATION_CLASS fic)
{
    NTSTATUS        ntStatus;
    IO_STATUS_BLOCK isb;

    NaAssert(pFileInformation);

    ntStatus = NtQueryInformationFile(hFile, &isb, pFileInformation,
      ulFileInformationSize, fic);
    if (ntStatus == STATUS_PENDING) {
        if (!NaWaitForFile(hFile, NULL)) {
            NaDbgPrintf(L"WaitForFile failed in QueryFileInfo!");
            return FALSE;
        }
        ntStatus = isb.Status;
        if (!NT_SUCCESS(ntStatus)) {
            NaDbgPrintf(
              L"QueryFileInfo failed after waiting (0x%08x)",
                ntStatus);
            return FALSE;
        }
    } else if (!NT_SUCCESS(ntStatus)) {
        NaDbgPrintf(L"QueryFileInfo failed (0x%08x)", ntStatus);
        return FALSE;
    }

    return TRUE;
}

BOOL NAAPI NaGetFileAttributes(HANDLE hFile, PULONG pulAttributes)
{
    FILE_BASIC_INFORMATION fbi;

    NaAssert(pulAttributes);

    if (!NaQueryFileInfo(hFile, &fbi, sizeof(fbi), FileBasicInformation)) {
        NaDbgPrintf(L"Cannot get file attributes!");
        return FALSE;
    }
    *pulAttributes = fbi.FileAttributes;

    return TRUE;
}

BOOL NAAPI NaGetFileLength(HANDLE hFile, PULONGLONG pullFileLength)
{
    FILE_STANDARD_INFORMATION fsi;

    NaAssert(pullFileLength);

    if (!NaQueryFileInfo(hFile, &fsi, sizeof(fsi), FileStandardInformation)) {
        NaDbgPrintf(L"Cannot get file length!");
        return FALSE;
    }
    *pullFileLength = fsi.EndOfFile.QuadPart;

    return TRUE;
}
